package VMOMI::DistributedVirtualPortgroupPortgroupType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
